# Documentation

## Hi there 👋

Over here we are developing PromG, a tool enabling you to perform multi-dimensional process analytics by exploiting a multi-layered Event Knowledge Graph.
The repository contains the source code (PromG-core) which can be installed as a Python package using `pip install promg` and several example analyses.

🎥 Demo Video: We created a demo video [here](https://www.youtube.com/watch?v=EKXFqHtW3Xw&t=6s). In this demo, we illustrate PromG on the BPIC'17 dataset.

🗃️ Documentation: [https://promg-dev.github.io/promg-core/](https://promg-dev.github.io/promg-core/)

🏁 Getting started: [https://promg-dev.github.io/promg-core/getting-started/](https://promg-dev.github.io/promg-core/getting-started/)

🛠️ Tutorial: [https://promg-dev.github.io/promg-core/tutorials](https://promg-dev.github.io/promg-core/tutorials/)

📦 Python Package: [https://pypi.org/project/promg/](https://pypi.org/project/promg/)
